# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/service/admin.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from flyteidl.admin import project_pb2 as flyteidl_dot_admin_dot_project__pb2
from flyteidl.admin import project_domain_attributes_pb2 as flyteidl_dot_admin_dot_project__domain__attributes__pb2
from flyteidl.admin import project_attributes_pb2 as flyteidl_dot_admin_dot_project__attributes__pb2
from flyteidl.admin import task_pb2 as flyteidl_dot_admin_dot_task__pb2
from flyteidl.admin import workflow_pb2 as flyteidl_dot_admin_dot_workflow__pb2
from flyteidl.admin import workflow_attributes_pb2 as flyteidl_dot_admin_dot_workflow__attributes__pb2
from flyteidl.admin import launch_plan_pb2 as flyteidl_dot_admin_dot_launch__plan__pb2
from flyteidl.admin import event_pb2 as flyteidl_dot_admin_dot_event__pb2
from flyteidl.admin import execution_pb2 as flyteidl_dot_admin_dot_execution__pb2
from flyteidl.admin import matchable_resource_pb2 as flyteidl_dot_admin_dot_matchable__resource__pb2
from flyteidl.admin import node_execution_pb2 as flyteidl_dot_admin_dot_node__execution__pb2
from flyteidl.admin import task_execution_pb2 as flyteidl_dot_admin_dot_task__execution__pb2
from flyteidl.admin import version_pb2 as flyteidl_dot_admin_dot_version__pb2
from flyteidl.admin import common_pb2 as flyteidl_dot_admin_dot_common__pb2
from flyteidl.admin import description_entity_pb2 as flyteidl_dot_admin_dot_description__entity__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/service/admin.proto',
  package='flyteidl.service',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/service'),
  serialized_pb=_b('\n\x1c\x66lyteidl/service/admin.proto\x12\x10\x66lyteidl.service\x1a\x1cgoogle/api/annotations.proto\x1a\x1c\x66lyteidl/admin/project.proto\x1a.flyteidl/admin/project_domain_attributes.proto\x1a\'flyteidl/admin/project_attributes.proto\x1a\x19\x66lyteidl/admin/task.proto\x1a\x1d\x66lyteidl/admin/workflow.proto\x1a(flyteidl/admin/workflow_attributes.proto\x1a flyteidl/admin/launch_plan.proto\x1a\x1a\x66lyteidl/admin/event.proto\x1a\x1e\x66lyteidl/admin/execution.proto\x1a\'flyteidl/admin/matchable_resource.proto\x1a#flyteidl/admin/node_execution.proto\x1a#flyteidl/admin/task_execution.proto\x1a\x1c\x66lyteidl/admin/version.proto\x1a\x1b\x66lyteidl/admin/common.proto\x1a\'flyteidl/admin/description_entity.proto2\x84N\n\x0c\x41\x64minService\x12m\n\nCreateTask\x12!.flyteidl.admin.TaskCreateRequest\x1a\".flyteidl.admin.TaskCreateResponse\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/api/v1/tasks:\x01*\x12\x88\x01\n\x07GetTask\x12 .flyteidl.admin.ObjectGetRequest\x1a\x14.flyteidl.admin.Task\"E\x82\xd3\xe4\x93\x02?\x12=/api/v1/tasks/{id.project}/{id.domain}/{id.name}/{id.version}\x12\x97\x01\n\x0bListTaskIds\x12\x30.flyteidl.admin.NamedEntityIdentifierListRequest\x1a).flyteidl.admin.NamedEntityIdentifierList\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1/task_ids/{project}/{domain}\x12\xae\x01\n\tListTasks\x12#.flyteidl.admin.ResourceListRequest\x1a\x18.flyteidl.admin.TaskList\"b\x82\xd3\xe4\x93\x02\\\x12\x30/api/v1/tasks/{id.project}/{id.domain}/{id.name}Z(\x12&/api/v1/tasks/{id.project}/{id.domain}\x12}\n\x0e\x43reateWorkflow\x12%.flyteidl.admin.WorkflowCreateRequest\x1a&.flyteidl.admin.WorkflowCreateResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/api/v1/workflows:\x01*\x12\x94\x01\n\x0bGetWorkflow\x12 .flyteidl.admin.ObjectGetRequest\x1a\x18.flyteidl.admin.Workflow\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/api/v1/workflows/{id.project}/{id.domain}/{id.name}/{id.version}\x12\x9f\x01\n\x0fListWorkflowIds\x12\x30.flyteidl.admin.NamedEntityIdentifierListRequest\x1a).flyteidl.admin.NamedEntityIdentifierList\"/\x82\xd3\xe4\x93\x02)\x12\'/api/v1/workflow_ids/{project}/{domain}\x12\xbe\x01\n\rListWorkflows\x12#.flyteidl.admin.ResourceListRequest\x1a\x1c.flyteidl.admin.WorkflowList\"j\x82\xd3\xe4\x93\x02\x64\x12\x34/api/v1/workflows/{id.project}/{id.domain}/{id.name}Z,\x12*/api/v1/workflows/{id.project}/{id.domain}\x12\x86\x01\n\x10\x43reateLaunchPlan\x12\'.flyteidl.admin.LaunchPlanCreateRequest\x1a(.flyteidl.admin.LaunchPlanCreateResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/api/v1/launch_plans:\x01*\x12\x9b\x01\n\rGetLaunchPlan\x12 .flyteidl.admin.ObjectGetRequest\x1a\x1a.flyteidl.admin.LaunchPlan\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/api/v1/launch_plans/{id.project}/{id.domain}/{id.name}/{id.version}\x12\xa2\x01\n\x13GetActiveLaunchPlan\x12\'.flyteidl.admin.ActiveLaunchPlanRequest\x1a\x1a.flyteidl.admin.LaunchPlan\"F\x82\xd3\xe4\x93\x02@\x12>/api/v1/active_launch_plans/{id.project}/{id.domain}/{id.name}\x12\x9c\x01\n\x15ListActiveLaunchPlans\x12+.flyteidl.admin.ActiveLaunchPlanListRequest\x1a\x1e.flyteidl.admin.LaunchPlanList\"6\x82\xd3\xe4\x93\x02\x30\x12./api/v1/active_launch_plans/{project}/{domain}\x12\xa4\x01\n\x11ListLaunchPlanIds\x12\x30.flyteidl.admin.NamedEntityIdentifierListRequest\x1a).flyteidl.admin.NamedEntityIdentifierList\"2\x82\xd3\xe4\x93\x02,\x12*/api/v1/launch_plan_ids/{project}/{domain}\x12\xc8\x01\n\x0fListLaunchPlans\x12#.flyteidl.admin.ResourceListRequest\x1a\x1e.flyteidl.admin.LaunchPlanList\"p\x82\xd3\xe4\x93\x02j\x12\x37/api/v1/launch_plans/{id.project}/{id.domain}/{id.name}Z/\x12-/api/v1/launch_plans/{id.project}/{id.domain}\x12\xb6\x01\n\x10UpdateLaunchPlan\x12\'.flyteidl.admin.LaunchPlanUpdateRequest\x1a(.flyteidl.admin.LaunchPlanUpdateResponse\"O\x82\xd3\xe4\x93\x02I\x1a\x44/api/v1/launch_plans/{id.project}/{id.domain}/{id.name}/{id.version}:\x01*\x12\x81\x01\n\x0f\x43reateExecution\x12&.flyteidl.admin.ExecutionCreateRequest\x1a\'.flyteidl.admin.ExecutionCreateResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/api/v1/executions:\x01*\x12\x8e\x01\n\x11RelaunchExecution\x12(.flyteidl.admin.ExecutionRelaunchRequest\x1a\'.flyteidl.admin.ExecutionCreateResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/api/v1/executions/relaunch:\x01*\x12\x8b\x01\n\x10RecoverExecution\x12\'.flyteidl.admin.ExecutionRecoverRequest\x1a\'.flyteidl.admin.ExecutionCreateResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/api/v1/executions/recover:\x01*\x12\x95\x01\n\x0cGetExecution\x12+.flyteidl.admin.WorkflowExecutionGetRequest\x1a\x19.flyteidl.admin.Execution\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/api/v1/executions/{id.project}/{id.domain}/{id.name}\x12\xa4\x01\n\x0fUpdateExecution\x12&.flyteidl.admin.ExecutionUpdateRequest\x1a\'.flyteidl.admin.ExecutionUpdateResponse\"@\x82\xd3\xe4\x93\x02:\x1a\x35/api/v1/executions/{id.project}/{id.domain}/{id.name}:\x01*\x12\xb9\x01\n\x10GetExecutionData\x12/.flyteidl.admin.WorkflowExecutionGetDataRequest\x1a\x30.flyteidl.admin.WorkflowExecutionGetDataResponse\"B\x82\xd3\xe4\x93\x02<\x12:/api/v1/data/executions/{id.project}/{id.domain}/{id.name}\x12\x89\x01\n\x0eListExecutions\x12#.flyteidl.admin.ResourceListRequest\x1a\x1d.flyteidl.admin.ExecutionList\"3\x82\xd3\xe4\x93\x02-\x12+/api/v1/executions/{id.project}/{id.domain}\x12\xad\x01\n\x12TerminateExecution\x12).flyteidl.admin.ExecutionTerminateRequest\x1a*.flyteidl.admin.ExecutionTerminateResponse\"@\x82\xd3\xe4\x93\x02:*5/api/v1/executions/{id.project}/{id.domain}/{id.name}:\x01*\x12\xd2\x01\n\x10GetNodeExecution\x12\'.flyteidl.admin.NodeExecutionGetRequest\x1a\x1d.flyteidl.admin.NodeExecution\"v\x82\xd3\xe4\x93\x02p\x12n/api/v1/node_executions/{id.execution_id.project}/{id.execution_id.domain}/{id.execution_id.name}/{id.node_id}\x12\xde\x01\n\x12ListNodeExecutions\x12(.flyteidl.admin.NodeExecutionListRequest\x1a!.flyteidl.admin.NodeExecutionList\"{\x82\xd3\xe4\x93\x02u\x12s/api/v1/node_executions/{workflow_execution_id.project}/{workflow_execution_id.domain}/{workflow_execution_id.name}\x12\xa5\x04\n\x19ListNodeExecutionsForTask\x12/.flyteidl.admin.NodeExecutionForTaskListRequest\x1a!.flyteidl.admin.NodeExecutionList\"\xb3\x03\x82\xd3\xe4\x93\x02\xac\x03\x12\xa9\x03/api/v1/children/task_executions/{task_execution_id.node_execution_id.execution_id.project}/{task_execution_id.node_execution_id.execution_id.domain}/{task_execution_id.node_execution_id.execution_id.name}/{task_execution_id.node_execution_id.node_id}/{task_execution_id.task_id.project}/{task_execution_id.task_id.domain}/{task_execution_id.task_id.name}/{task_execution_id.task_id.version}/{task_execution_id.retry_attempt}\x12\xee\x01\n\x14GetNodeExecutionData\x12+.flyteidl.admin.NodeExecutionGetDataRequest\x1a,.flyteidl.admin.NodeExecutionGetDataResponse\"{\x82\xd3\xe4\x93\x02u\x12s/api/v1/data/node_executions/{id.execution_id.project}/{id.execution_id.domain}/{id.execution_id.name}/{id.node_id}\x12\x7f\n\x0fRegisterProject\x12&.flyteidl.admin.ProjectRegisterRequest\x1a\'.flyteidl.admin.ProjectRegisterResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/api/v1/projects:\x01*\x12q\n\rUpdateProject\x12\x17.flyteidl.admin.Project\x1a%.flyteidl.admin.ProjectUpdateResponse\" \x82\xd3\xe4\x93\x02\x1a\x1a\x15/api/v1/projects/{id}:\x01*\x12\x66\n\x0cListProjects\x12\".flyteidl.admin.ProjectListRequest\x1a\x18.flyteidl.admin.Projects\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v1/projects\x12\x99\x01\n\x13\x43reateWorkflowEvent\x12-.flyteidl.admin.WorkflowExecutionEventRequest\x1a..flyteidl.admin.WorkflowExecutionEventResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/api/v1/events/workflows:\x01*\x12\x89\x01\n\x0f\x43reateNodeEvent\x12).flyteidl.admin.NodeExecutionEventRequest\x1a*.flyteidl.admin.NodeExecutionEventResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/api/v1/events/nodes:\x01*\x12\x89\x01\n\x0f\x43reateTaskEvent\x12).flyteidl.admin.TaskExecutionEventRequest\x1a*.flyteidl.admin.TaskExecutionEventResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/api/v1/events/tasks:\x01*\x12\x80\x03\n\x10GetTaskExecution\x12\'.flyteidl.admin.TaskExecutionGetRequest\x1a\x1d.flyteidl.admin.TaskExecution\"\xa3\x02\x82\xd3\xe4\x93\x02\x9c\x02\x12\x99\x02/api/v1/task_executions/{id.node_execution_id.execution_id.project}/{id.node_execution_id.execution_id.domain}/{id.node_execution_id.execution_id.name}/{id.node_execution_id.node_id}/{id.task_id.project}/{id.task_id.domain}/{id.task_id.name}/{id.task_id.version}/{id.retry_attempt}\x12\x98\x02\n\x12ListTaskExecutions\x12(.flyteidl.admin.TaskExecutionListRequest\x1a!.flyteidl.admin.TaskExecutionList\"\xb4\x01\x82\xd3\xe4\x93\x02\xad\x01\x12\xaa\x01/api/v1/task_executions/{node_execution_id.execution_id.project}/{node_execution_id.execution_id.domain}/{node_execution_id.execution_id.name}/{node_execution_id.node_id}\x12\x9c\x03\n\x14GetTaskExecutionData\x12+.flyteidl.admin.TaskExecutionGetDataRequest\x1a,.flyteidl.admin.TaskExecutionGetDataResponse\"\xa8\x02\x82\xd3\xe4\x93\x02\xa1\x02\x12\x9e\x02/api/v1/data/task_executions/{id.node_execution_id.execution_id.project}/{id.node_execution_id.execution_id.domain}/{id.node_execution_id.execution_id.name}/{id.node_execution_id.node_id}/{id.task_id.project}/{id.task_id.domain}/{id.task_id.name}/{id.task_id.version}/{id.retry_attempt}\x12\xe3\x01\n\x1dUpdateProjectDomainAttributes\x12\x34.flyteidl.admin.ProjectDomainAttributesUpdateRequest\x1a\x35.flyteidl.admin.ProjectDomainAttributesUpdateResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/api/v1/project_domain_attributes/{attributes.project}/{attributes.domain}:\x01*\x12\xc1\x01\n\x1aGetProjectDomainAttributes\x12\x31.flyteidl.admin.ProjectDomainAttributesGetRequest\x1a\x32.flyteidl.admin.ProjectDomainAttributesGetResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/api/v1/project_domain_attributes/{project}/{domain}\x12\xcd\x01\n\x1d\x44\x65leteProjectDomainAttributes\x12\x34.flyteidl.admin.ProjectDomainAttributesDeleteRequest\x1a\x35.flyteidl.admin.ProjectDomainAttributesDeleteResponse\"?\x82\xd3\xe4\x93\x02\x39*4/api/v1/project_domain_attributes/{project}/{domain}:\x01*\x12\xb6\x01\n\x17UpdateProjectAttributes\x12..flyteidl.admin.ProjectAttributesUpdateRequest\x1a/.flyteidl.admin.ProjectAttributesUpdateResponse\":\x82\xd3\xe4\x93\x02\x34\x1a//api/v1/project_attributes/{attributes.project}:\x01*\x12\x9f\x01\n\x14GetProjectAttributes\x12+.flyteidl.admin.ProjectAttributesGetRequest\x1a,.flyteidl.admin.ProjectAttributesGetResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/project_attributes/{project}\x12\xab\x01\n\x17\x44\x65leteProjectAttributes\x12..flyteidl.admin.ProjectAttributesDeleteRequest\x1a/.flyteidl.admin.ProjectAttributesDeleteResponse\"/\x82\xd3\xe4\x93\x02)*$/api/v1/project_attributes/{project}:\x01*\x12\xe4\x01\n\x18UpdateWorkflowAttributes\x12/.flyteidl.admin.WorkflowAttributesUpdateRequest\x1a\x30.flyteidl.admin.WorkflowAttributesUpdateResponse\"e\x82\xd3\xe4\x93\x02_\x1aZ/api/v1/workflow_attributes/{attributes.project}/{attributes.domain}/{attributes.workflow}:\x01*\x12\xb7\x01\n\x15GetWorkflowAttributes\x12,.flyteidl.admin.WorkflowAttributesGetRequest\x1a-.flyteidl.admin.WorkflowAttributesGetResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/api/v1/workflow_attributes/{project}/{domain}/{workflow}\x12\xc3\x01\n\x18\x44\x65leteWorkflowAttributes\x12/.flyteidl.admin.WorkflowAttributesDeleteRequest\x1a\x30.flyteidl.admin.WorkflowAttributesDeleteResponse\"D\x82\xd3\xe4\x93\x02>*9/api/v1/workflow_attributes/{project}/{domain}/{workflow}:\x01*\x12\xa0\x01\n\x17ListMatchableAttributes\x12..flyteidl.admin.ListMatchableAttributesRequest\x1a/.flyteidl.admin.ListMatchableAttributesResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/matchable_attributes\x12\x9f\x01\n\x11ListNamedEntities\x12&.flyteidl.admin.NamedEntityListRequest\x1a\x1f.flyteidl.admin.NamedEntityList\"A\x82\xd3\xe4\x93\x02;\x12\x39/api/v1/named_entities/{resource_type}/{project}/{domain}\x12\xa7\x01\n\x0eGetNamedEntity\x12%.flyteidl.admin.NamedEntityGetRequest\x1a\x1b.flyteidl.admin.NamedEntity\"Q\x82\xd3\xe4\x93\x02K\x12I/api/v1/named_entities/{resource_type}/{id.project}/{id.domain}/{id.name}\x12\xbe\x01\n\x11UpdateNamedEntity\x12(.flyteidl.admin.NamedEntityUpdateRequest\x1a).flyteidl.admin.NamedEntityUpdateResponse\"T\x82\xd3\xe4\x93\x02N\x1aI/api/v1/named_entities/{resource_type}/{id.project}/{id.domain}/{id.name}:\x01*\x12l\n\nGetVersion\x12!.flyteidl.admin.GetVersionRequest\x1a\".flyteidl.admin.GetVersionResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/api/v1/version\x12\xc4\x01\n\x14GetDescriptionEntity\x12 .flyteidl.admin.ObjectGetRequest\x1a!.flyteidl.admin.DescriptionEntity\"g\x82\xd3\xe4\x93\x02\x61\x12_/api/v1/description_entities/{id.resource_type}/{id.project}/{id.domain}/{id.name}/{id.version}\x12\x92\x02\n\x17ListDescriptionEntities\x12,.flyteidl.admin.DescriptionEntityListRequest\x1a%.flyteidl.admin.DescriptionEntityList\"\xa1\x01\x82\xd3\xe4\x93\x02\x9a\x01\x12O/api/v1/description_entities/{resource_type}/{id.project}/{id.domain}/{id.name}ZG\x12\x45/api/v1/description_entities/{resource_type}/{id.project}/{id.domain}\x12\xc5\x01\n\x13GetExecutionMetrics\x12\x32.flyteidl.admin.WorkflowExecutionGetMetricsRequest\x1a\x33.flyteidl.admin.WorkflowExecutionGetMetricsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/api/v1/metrics/executions/{id.project}/{id.domain}/{id.name}B9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/serviceb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_project__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_project__domain__attributes__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_project__attributes__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_task__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_workflow__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_workflow__attributes__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_launch__plan__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_event__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_execution__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_matchable__resource__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_node__execution__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_task__execution__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_version__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_common__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_description__entity__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_ADMINSERVICE = _descriptor.ServiceDescriptor(
  name='AdminService',
  full_name='flyteidl.service.AdminService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=609,
  serialized_end=10597,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateTask',
    full_name='flyteidl.service.AdminService.CreateTask',
    index=0,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_task__pb2._TASKCREATEREQUEST,
    output_type=flyteidl_dot_admin_dot_task__pb2._TASKCREATERESPONSE,
    serialized_options=_b('\202\323\344\223\002\022\"\r/api/v1/tasks:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetTask',
    full_name='flyteidl.service.AdminService.GetTask',
    index=1,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._OBJECTGETREQUEST,
    output_type=flyteidl_dot_admin_dot_task__pb2._TASK,
    serialized_options=_b('\202\323\344\223\002?\022=/api/v1/tasks/{id.project}/{id.domain}/{id.name}/{id.version}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListTaskIds',
    full_name='flyteidl.service.AdminService.ListTaskIds',
    index=2,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYIDENTIFIERLISTREQUEST,
    output_type=flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYIDENTIFIERLIST,
    serialized_options=_b('\202\323\344\223\002%\022#/api/v1/task_ids/{project}/{domain}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListTasks',
    full_name='flyteidl.service.AdminService.ListTasks',
    index=3,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._RESOURCELISTREQUEST,
    output_type=flyteidl_dot_admin_dot_task__pb2._TASKLIST,
    serialized_options=_b('\202\323\344\223\002\\\0220/api/v1/tasks/{id.project}/{id.domain}/{id.name}Z(\022&/api/v1/tasks/{id.project}/{id.domain}'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateWorkflow',
    full_name='flyteidl.service.AdminService.CreateWorkflow',
    index=4,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_workflow__pb2._WORKFLOWCREATEREQUEST,
    output_type=flyteidl_dot_admin_dot_workflow__pb2._WORKFLOWCREATERESPONSE,
    serialized_options=_b('\202\323\344\223\002\026\"\021/api/v1/workflows:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetWorkflow',
    full_name='flyteidl.service.AdminService.GetWorkflow',
    index=5,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._OBJECTGETREQUEST,
    output_type=flyteidl_dot_admin_dot_workflow__pb2._WORKFLOW,
    serialized_options=_b('\202\323\344\223\002C\022A/api/v1/workflows/{id.project}/{id.domain}/{id.name}/{id.version}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListWorkflowIds',
    full_name='flyteidl.service.AdminService.ListWorkflowIds',
    index=6,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYIDENTIFIERLISTREQUEST,
    output_type=flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYIDENTIFIERLIST,
    serialized_options=_b('\202\323\344\223\002)\022\'/api/v1/workflow_ids/{project}/{domain}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListWorkflows',
    full_name='flyteidl.service.AdminService.ListWorkflows',
    index=7,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._RESOURCELISTREQUEST,
    output_type=flyteidl_dot_admin_dot_workflow__pb2._WORKFLOWLIST,
    serialized_options=_b('\202\323\344\223\002d\0224/api/v1/workflows/{id.project}/{id.domain}/{id.name}Z,\022*/api/v1/workflows/{id.project}/{id.domain}'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateLaunchPlan',
    full_name='flyteidl.service.AdminService.CreateLaunchPlan',
    index=8,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_launch__plan__pb2._LAUNCHPLANCREATEREQUEST,
    output_type=flyteidl_dot_admin_dot_launch__plan__pb2._LAUNCHPLANCREATERESPONSE,
    serialized_options=_b('\202\323\344\223\002\031\"\024/api/v1/launch_plans:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetLaunchPlan',
    full_name='flyteidl.service.AdminService.GetLaunchPlan',
    index=9,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._OBJECTGETREQUEST,
    output_type=flyteidl_dot_admin_dot_launch__plan__pb2._LAUNCHPLAN,
    serialized_options=_b('\202\323\344\223\002F\022D/api/v1/launch_plans/{id.project}/{id.domain}/{id.name}/{id.version}'),
  ),
  _descriptor.MethodDescriptor(
    name='GetActiveLaunchPlan',
    full_name='flyteidl.service.AdminService.GetActiveLaunchPlan',
    index=10,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_launch__plan__pb2._ACTIVELAUNCHPLANREQUEST,
    output_type=flyteidl_dot_admin_dot_launch__plan__pb2._LAUNCHPLAN,
    serialized_options=_b('\202\323\344\223\002@\022>/api/v1/active_launch_plans/{id.project}/{id.domain}/{id.name}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListActiveLaunchPlans',
    full_name='flyteidl.service.AdminService.ListActiveLaunchPlans',
    index=11,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_launch__plan__pb2._ACTIVELAUNCHPLANLISTREQUEST,
    output_type=flyteidl_dot_admin_dot_launch__plan__pb2._LAUNCHPLANLIST,
    serialized_options=_b('\202\323\344\223\0020\022./api/v1/active_launch_plans/{project}/{domain}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListLaunchPlanIds',
    full_name='flyteidl.service.AdminService.ListLaunchPlanIds',
    index=12,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYIDENTIFIERLISTREQUEST,
    output_type=flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYIDENTIFIERLIST,
    serialized_options=_b('\202\323\344\223\002,\022*/api/v1/launch_plan_ids/{project}/{domain}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListLaunchPlans',
    full_name='flyteidl.service.AdminService.ListLaunchPlans',
    index=13,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._RESOURCELISTREQUEST,
    output_type=flyteidl_dot_admin_dot_launch__plan__pb2._LAUNCHPLANLIST,
    serialized_options=_b('\202\323\344\223\002j\0227/api/v1/launch_plans/{id.project}/{id.domain}/{id.name}Z/\022-/api/v1/launch_plans/{id.project}/{id.domain}'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLaunchPlan',
    full_name='flyteidl.service.AdminService.UpdateLaunchPlan',
    index=14,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_launch__plan__pb2._LAUNCHPLANUPDATEREQUEST,
    output_type=flyteidl_dot_admin_dot_launch__plan__pb2._LAUNCHPLANUPDATERESPONSE,
    serialized_options=_b('\202\323\344\223\002I\032D/api/v1/launch_plans/{id.project}/{id.domain}/{id.name}/{id.version}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateExecution',
    full_name='flyteidl.service.AdminService.CreateExecution',
    index=15,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_execution__pb2._EXECUTIONCREATEREQUEST,
    output_type=flyteidl_dot_admin_dot_execution__pb2._EXECUTIONCREATERESPONSE,
    serialized_options=_b('\202\323\344\223\002\027\"\022/api/v1/executions:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='RelaunchExecution',
    full_name='flyteidl.service.AdminService.RelaunchExecution',
    index=16,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_execution__pb2._EXECUTIONRELAUNCHREQUEST,
    output_type=flyteidl_dot_admin_dot_execution__pb2._EXECUTIONCREATERESPONSE,
    serialized_options=_b('\202\323\344\223\002 \"\033/api/v1/executions/relaunch:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='RecoverExecution',
    full_name='flyteidl.service.AdminService.RecoverExecution',
    index=17,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_execution__pb2._EXECUTIONRECOVERREQUEST,
    output_type=flyteidl_dot_admin_dot_execution__pb2._EXECUTIONCREATERESPONSE,
    serialized_options=_b('\202\323\344\223\002\037\"\032/api/v1/executions/recover:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetExecution',
    full_name='flyteidl.service.AdminService.GetExecution',
    index=18,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_execution__pb2._WORKFLOWEXECUTIONGETREQUEST,
    output_type=flyteidl_dot_admin_dot_execution__pb2._EXECUTION,
    serialized_options=_b('\202\323\344\223\0027\0225/api/v1/executions/{id.project}/{id.domain}/{id.name}'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateExecution',
    full_name='flyteidl.service.AdminService.UpdateExecution',
    index=19,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_execution__pb2._EXECUTIONUPDATEREQUEST,
    output_type=flyteidl_dot_admin_dot_execution__pb2._EXECUTIONUPDATERESPONSE,
    serialized_options=_b('\202\323\344\223\002:\0325/api/v1/executions/{id.project}/{id.domain}/{id.name}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetExecutionData',
    full_name='flyteidl.service.AdminService.GetExecutionData',
    index=20,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_execution__pb2._WORKFLOWEXECUTIONGETDATAREQUEST,
    output_type=flyteidl_dot_admin_dot_execution__pb2._WORKFLOWEXECUTIONGETDATARESPONSE,
    serialized_options=_b('\202\323\344\223\002<\022:/api/v1/data/executions/{id.project}/{id.domain}/{id.name}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListExecutions',
    full_name='flyteidl.service.AdminService.ListExecutions',
    index=21,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._RESOURCELISTREQUEST,
    output_type=flyteidl_dot_admin_dot_execution__pb2._EXECUTIONLIST,
    serialized_options=_b('\202\323\344\223\002-\022+/api/v1/executions/{id.project}/{id.domain}'),
  ),
  _descriptor.MethodDescriptor(
    name='TerminateExecution',
    full_name='flyteidl.service.AdminService.TerminateExecution',
    index=22,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_execution__pb2._EXECUTIONTERMINATEREQUEST,
    output_type=flyteidl_dot_admin_dot_execution__pb2._EXECUTIONTERMINATERESPONSE,
    serialized_options=_b('\202\323\344\223\002:*5/api/v1/executions/{id.project}/{id.domain}/{id.name}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetNodeExecution',
    full_name='flyteidl.service.AdminService.GetNodeExecution',
    index=23,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_node__execution__pb2._NODEEXECUTIONGETREQUEST,
    output_type=flyteidl_dot_admin_dot_node__execution__pb2._NODEEXECUTION,
    serialized_options=_b('\202\323\344\223\002p\022n/api/v1/node_executions/{id.execution_id.project}/{id.execution_id.domain}/{id.execution_id.name}/{id.node_id}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListNodeExecutions',
    full_name='flyteidl.service.AdminService.ListNodeExecutions',
    index=24,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_node__execution__pb2._NODEEXECUTIONLISTREQUEST,
    output_type=flyteidl_dot_admin_dot_node__execution__pb2._NODEEXECUTIONLIST,
    serialized_options=_b('\202\323\344\223\002u\022s/api/v1/node_executions/{workflow_execution_id.project}/{workflow_execution_id.domain}/{workflow_execution_id.name}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListNodeExecutionsForTask',
    full_name='flyteidl.service.AdminService.ListNodeExecutionsForTask',
    index=25,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_node__execution__pb2._NODEEXECUTIONFORTASKLISTREQUEST,
    output_type=flyteidl_dot_admin_dot_node__execution__pb2._NODEEXECUTIONLIST,
    serialized_options=_b('\202\323\344\223\002\254\003\022\251\003/api/v1/children/task_executions/{task_execution_id.node_execution_id.execution_id.project}/{task_execution_id.node_execution_id.execution_id.domain}/{task_execution_id.node_execution_id.execution_id.name}/{task_execution_id.node_execution_id.node_id}/{task_execution_id.task_id.project}/{task_execution_id.task_id.domain}/{task_execution_id.task_id.name}/{task_execution_id.task_id.version}/{task_execution_id.retry_attempt}'),
  ),
  _descriptor.MethodDescriptor(
    name='GetNodeExecutionData',
    full_name='flyteidl.service.AdminService.GetNodeExecutionData',
    index=26,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_node__execution__pb2._NODEEXECUTIONGETDATAREQUEST,
    output_type=flyteidl_dot_admin_dot_node__execution__pb2._NODEEXECUTIONGETDATARESPONSE,
    serialized_options=_b('\202\323\344\223\002u\022s/api/v1/data/node_executions/{id.execution_id.project}/{id.execution_id.domain}/{id.execution_id.name}/{id.node_id}'),
  ),
  _descriptor.MethodDescriptor(
    name='RegisterProject',
    full_name='flyteidl.service.AdminService.RegisterProject',
    index=27,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_project__pb2._PROJECTREGISTERREQUEST,
    output_type=flyteidl_dot_admin_dot_project__pb2._PROJECTREGISTERRESPONSE,
    serialized_options=_b('\202\323\344\223\002\025\"\020/api/v1/projects:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProject',
    full_name='flyteidl.service.AdminService.UpdateProject',
    index=28,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_project__pb2._PROJECT,
    output_type=flyteidl_dot_admin_dot_project__pb2._PROJECTUPDATERESPONSE,
    serialized_options=_b('\202\323\344\223\002\032\032\025/api/v1/projects/{id}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ListProjects',
    full_name='flyteidl.service.AdminService.ListProjects',
    index=29,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_project__pb2._PROJECTLISTREQUEST,
    output_type=flyteidl_dot_admin_dot_project__pb2._PROJECTS,
    serialized_options=_b('\202\323\344\223\002\022\022\020/api/v1/projects'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateWorkflowEvent',
    full_name='flyteidl.service.AdminService.CreateWorkflowEvent',
    index=30,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_event__pb2._WORKFLOWEXECUTIONEVENTREQUEST,
    output_type=flyteidl_dot_admin_dot_event__pb2._WORKFLOWEXECUTIONEVENTRESPONSE,
    serialized_options=_b('\202\323\344\223\002\035\"\030/api/v1/events/workflows:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateNodeEvent',
    full_name='flyteidl.service.AdminService.CreateNodeEvent',
    index=31,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_event__pb2._NODEEXECUTIONEVENTREQUEST,
    output_type=flyteidl_dot_admin_dot_event__pb2._NODEEXECUTIONEVENTRESPONSE,
    serialized_options=_b('\202\323\344\223\002\031\"\024/api/v1/events/nodes:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateTaskEvent',
    full_name='flyteidl.service.AdminService.CreateTaskEvent',
    index=32,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_event__pb2._TASKEXECUTIONEVENTREQUEST,
    output_type=flyteidl_dot_admin_dot_event__pb2._TASKEXECUTIONEVENTRESPONSE,
    serialized_options=_b('\202\323\344\223\002\031\"\024/api/v1/events/tasks:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetTaskExecution',
    full_name='flyteidl.service.AdminService.GetTaskExecution',
    index=33,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_task__execution__pb2._TASKEXECUTIONGETREQUEST,
    output_type=flyteidl_dot_admin_dot_task__execution__pb2._TASKEXECUTION,
    serialized_options=_b('\202\323\344\223\002\234\002\022\231\002/api/v1/task_executions/{id.node_execution_id.execution_id.project}/{id.node_execution_id.execution_id.domain}/{id.node_execution_id.execution_id.name}/{id.node_execution_id.node_id}/{id.task_id.project}/{id.task_id.domain}/{id.task_id.name}/{id.task_id.version}/{id.retry_attempt}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListTaskExecutions',
    full_name='flyteidl.service.AdminService.ListTaskExecutions',
    index=34,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_task__execution__pb2._TASKEXECUTIONLISTREQUEST,
    output_type=flyteidl_dot_admin_dot_task__execution__pb2._TASKEXECUTIONLIST,
    serialized_options=_b('\202\323\344\223\002\255\001\022\252\001/api/v1/task_executions/{node_execution_id.execution_id.project}/{node_execution_id.execution_id.domain}/{node_execution_id.execution_id.name}/{node_execution_id.node_id}'),
  ),
  _descriptor.MethodDescriptor(
    name='GetTaskExecutionData',
    full_name='flyteidl.service.AdminService.GetTaskExecutionData',
    index=35,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_task__execution__pb2._TASKEXECUTIONGETDATAREQUEST,
    output_type=flyteidl_dot_admin_dot_task__execution__pb2._TASKEXECUTIONGETDATARESPONSE,
    serialized_options=_b('\202\323\344\223\002\241\002\022\236\002/api/v1/data/task_executions/{id.node_execution_id.execution_id.project}/{id.node_execution_id.execution_id.domain}/{id.node_execution_id.execution_id.name}/{id.node_execution_id.node_id}/{id.task_id.project}/{id.task_id.domain}/{id.task_id.name}/{id.task_id.version}/{id.retry_attempt}'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProjectDomainAttributes',
    full_name='flyteidl.service.AdminService.UpdateProjectDomainAttributes',
    index=36,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_project__domain__attributes__pb2._PROJECTDOMAINATTRIBUTESUPDATEREQUEST,
    output_type=flyteidl_dot_admin_dot_project__domain__attributes__pb2._PROJECTDOMAINATTRIBUTESUPDATERESPONSE,
    serialized_options=_b('\202\323\344\223\002O\032J/api/v1/project_domain_attributes/{attributes.project}/{attributes.domain}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetProjectDomainAttributes',
    full_name='flyteidl.service.AdminService.GetProjectDomainAttributes',
    index=37,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_project__domain__attributes__pb2._PROJECTDOMAINATTRIBUTESGETREQUEST,
    output_type=flyteidl_dot_admin_dot_project__domain__attributes__pb2._PROJECTDOMAINATTRIBUTESGETRESPONSE,
    serialized_options=_b('\202\323\344\223\0026\0224/api/v1/project_domain_attributes/{project}/{domain}'),
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProjectDomainAttributes',
    full_name='flyteidl.service.AdminService.DeleteProjectDomainAttributes',
    index=38,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_project__domain__attributes__pb2._PROJECTDOMAINATTRIBUTESDELETEREQUEST,
    output_type=flyteidl_dot_admin_dot_project__domain__attributes__pb2._PROJECTDOMAINATTRIBUTESDELETERESPONSE,
    serialized_options=_b('\202\323\344\223\0029*4/api/v1/project_domain_attributes/{project}/{domain}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProjectAttributes',
    full_name='flyteidl.service.AdminService.UpdateProjectAttributes',
    index=39,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_project__attributes__pb2._PROJECTATTRIBUTESUPDATEREQUEST,
    output_type=flyteidl_dot_admin_dot_project__attributes__pb2._PROJECTATTRIBUTESUPDATERESPONSE,
    serialized_options=_b('\202\323\344\223\0024\032//api/v1/project_attributes/{attributes.project}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetProjectAttributes',
    full_name='flyteidl.service.AdminService.GetProjectAttributes',
    index=40,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_project__attributes__pb2._PROJECTATTRIBUTESGETREQUEST,
    output_type=flyteidl_dot_admin_dot_project__attributes__pb2._PROJECTATTRIBUTESGETRESPONSE,
    serialized_options=_b('\202\323\344\223\002&\022$/api/v1/project_attributes/{project}'),
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProjectAttributes',
    full_name='flyteidl.service.AdminService.DeleteProjectAttributes',
    index=41,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_project__attributes__pb2._PROJECTATTRIBUTESDELETEREQUEST,
    output_type=flyteidl_dot_admin_dot_project__attributes__pb2._PROJECTATTRIBUTESDELETERESPONSE,
    serialized_options=_b('\202\323\344\223\002)*$/api/v1/project_attributes/{project}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateWorkflowAttributes',
    full_name='flyteidl.service.AdminService.UpdateWorkflowAttributes',
    index=42,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_workflow__attributes__pb2._WORKFLOWATTRIBUTESUPDATEREQUEST,
    output_type=flyteidl_dot_admin_dot_workflow__attributes__pb2._WORKFLOWATTRIBUTESUPDATERESPONSE,
    serialized_options=_b('\202\323\344\223\002_\032Z/api/v1/workflow_attributes/{attributes.project}/{attributes.domain}/{attributes.workflow}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetWorkflowAttributes',
    full_name='flyteidl.service.AdminService.GetWorkflowAttributes',
    index=43,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_workflow__attributes__pb2._WORKFLOWATTRIBUTESGETREQUEST,
    output_type=flyteidl_dot_admin_dot_workflow__attributes__pb2._WORKFLOWATTRIBUTESGETRESPONSE,
    serialized_options=_b('\202\323\344\223\002;\0229/api/v1/workflow_attributes/{project}/{domain}/{workflow}'),
  ),
  _descriptor.MethodDescriptor(
    name='DeleteWorkflowAttributes',
    full_name='flyteidl.service.AdminService.DeleteWorkflowAttributes',
    index=44,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_workflow__attributes__pb2._WORKFLOWATTRIBUTESDELETEREQUEST,
    output_type=flyteidl_dot_admin_dot_workflow__attributes__pb2._WORKFLOWATTRIBUTESDELETERESPONSE,
    serialized_options=_b('\202\323\344\223\002>*9/api/v1/workflow_attributes/{project}/{domain}/{workflow}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ListMatchableAttributes',
    full_name='flyteidl.service.AdminService.ListMatchableAttributes',
    index=45,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_matchable__resource__pb2._LISTMATCHABLEATTRIBUTESREQUEST,
    output_type=flyteidl_dot_admin_dot_matchable__resource__pb2._LISTMATCHABLEATTRIBUTESRESPONSE,
    serialized_options=_b('\202\323\344\223\002\036\022\034/api/v1/matchable_attributes'),
  ),
  _descriptor.MethodDescriptor(
    name='ListNamedEntities',
    full_name='flyteidl.service.AdminService.ListNamedEntities',
    index=46,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYLISTREQUEST,
    output_type=flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYLIST,
    serialized_options=_b('\202\323\344\223\002;\0229/api/v1/named_entities/{resource_type}/{project}/{domain}'),
  ),
  _descriptor.MethodDescriptor(
    name='GetNamedEntity',
    full_name='flyteidl.service.AdminService.GetNamedEntity',
    index=47,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYGETREQUEST,
    output_type=flyteidl_dot_admin_dot_common__pb2._NAMEDENTITY,
    serialized_options=_b('\202\323\344\223\002K\022I/api/v1/named_entities/{resource_type}/{id.project}/{id.domain}/{id.name}'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateNamedEntity',
    full_name='flyteidl.service.AdminService.UpdateNamedEntity',
    index=48,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYUPDATEREQUEST,
    output_type=flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYUPDATERESPONSE,
    serialized_options=_b('\202\323\344\223\002N\032I/api/v1/named_entities/{resource_type}/{id.project}/{id.domain}/{id.name}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetVersion',
    full_name='flyteidl.service.AdminService.GetVersion',
    index=49,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_version__pb2._GETVERSIONREQUEST,
    output_type=flyteidl_dot_admin_dot_version__pb2._GETVERSIONRESPONSE,
    serialized_options=_b('\202\323\344\223\002\021\022\017/api/v1/version'),
  ),
  _descriptor.MethodDescriptor(
    name='GetDescriptionEntity',
    full_name='flyteidl.service.AdminService.GetDescriptionEntity',
    index=50,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_common__pb2._OBJECTGETREQUEST,
    output_type=flyteidl_dot_admin_dot_description__entity__pb2._DESCRIPTIONENTITY,
    serialized_options=_b('\202\323\344\223\002a\022_/api/v1/description_entities/{id.resource_type}/{id.project}/{id.domain}/{id.name}/{id.version}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListDescriptionEntities',
    full_name='flyteidl.service.AdminService.ListDescriptionEntities',
    index=51,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_description__entity__pb2._DESCRIPTIONENTITYLISTREQUEST,
    output_type=flyteidl_dot_admin_dot_description__entity__pb2._DESCRIPTIONENTITYLIST,
    serialized_options=_b('\202\323\344\223\002\232\001\022O/api/v1/description_entities/{resource_type}/{id.project}/{id.domain}/{id.name}ZG\022E/api/v1/description_entities/{resource_type}/{id.project}/{id.domain}'),
  ),
  _descriptor.MethodDescriptor(
    name='GetExecutionMetrics',
    full_name='flyteidl.service.AdminService.GetExecutionMetrics',
    index=52,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_execution__pb2._WORKFLOWEXECUTIONGETMETRICSREQUEST,
    output_type=flyteidl_dot_admin_dot_execution__pb2._WORKFLOWEXECUTIONGETMETRICSRESPONSE,
    serialized_options=_b('\202\323\344\223\002?\022=/api/v1/metrics/executions/{id.project}/{id.domain}/{id.name}'),
  ),
])
_sym_db.RegisterServiceDescriptor(_ADMINSERVICE)

DESCRIPTOR.services_by_name['AdminService'] = _ADMINSERVICE

# @@protoc_insertion_point(module_scope)
